#
# spec file for package perl-PAR
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-PAR
Version:        1.010
Release:        3.1
%define cpan_name PAR
Summary:        Perl Archive Toolkit
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/PAR/
Source0:        http://www.cpan.org/authors/id/R/RS/RSCHUPP/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Archive::Zip) >= 1
BuildRequires:  perl(AutoLoader) >= 5.66_02
BuildRequires:  perl(Compress::Zlib) >= 1.3
BuildRequires:  perl(PAR::Dist) >= 0.32
Requires:       perl(Archive::Zip) >= 1
Requires:       perl(AutoLoader) >= 5.66_02
Requires:       perl(Compress::Zlib) >= 1.3
Requires:       perl(PAR::Dist) >= 0.32
Recommends:     perl(Digest) >= Module::Signature
%{perl_requires}

%description
This module lets you use special zip files, called *P*erl *Ar*chives, as
libraries from which Perl modules can be loaded.

It supports loading XS modules by overriding *DynaLoader* bootstrapping
methods; it writes shared object file to a temporary file at the time it is
needed.

A _.par_ file is mostly a zip of the _blib/_ directory after the build
process of a CPAN distribution. To generate a _.par_ file yourself, all you
have to do is compress the modules under _arch/_ and _lib/_, e.g.:

    % perl Makefile.PL
    % make
    % cd blib
    % zip -r mymodule.par arch/ lib/

Afterward, you can just use _mymodule.par_ anywhere in your '@INC', use
*PAR*, and it will Just Work. Support for generating _.par_ files is going
to be in the next (beyond 0.2805) release of Module::Build.

For convenience, you can set the 'PERL5OPT' environment variable to '-MPAR'
to enable 'PAR' processing globally (the overhead is small if not used);
setting it to '-MPAR=/path/to/mylib.par' will load a specific PAR file.
Alternatively, consider using the _par.pl_ utility bundled with the the
PAR::Packer manpage distribution, or using the self-contained _parl_
utility which is also distributed with the PAR::Packer manpage on machines
without PAR.pm installed.

Note that self-containing scripts and executables created with _par.pl_ and
_pp_ may also be used as _.par_ archives:

    % pp -o packed.exe source.pl        # generate packed.exe (see PAR::Packer)
    % perl -MPAR=packed.exe other.pl    # this also works
    % perl -MPAR -Ipacked.exe other.pl  # ditto

Please see the /SYNOPSIS manpage for most typical use cases.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc AUTHORS Changes README TODO

%changelog
* Sat Aug  1 2015 coolo@suse.com
- updated to 1.010
  see /usr/share/doc/packages/perl-PAR/Changes
  1.010  2015-07-13
  - Fix #101800 "[PATCH] Reinstate files to inc dir if deleted by external process"
    Periodic temp  directory cleaning programs (eg. "tmpwatch") may remove some
    (older) files from $PAR_TEMP/inc, but keep others. This causes the packed
    program to fail.
  - When extracting a .par file to $PAR_TEMP/inc do NOT restore the original
    modified timestamps of the file (so that the extracted files have
    the time of extraction as their modified time).
  - Add a "canary" file in $PAR_TEMP and back-date it 1 day. Hence any process
    removing files in $PAR_TEMP based on timestamps should remove
    the "canary" before others.
  - If the canary file is missing, extract the .par to $PAR_TEMP/inc
    as previously was done only when $PAR_TEMP/inc was missing.
* Fri Apr 24 2015 coolo@suse.com
- updated to 1.009
  see /usr/share/doc/packages/perl-PAR/Changes
  1.009  2015-04-22
  - Fix 103861 for PAR-Packer: Adding local directories to @INC for a pp executable fails
  - Get rid of included PerlIO.pm, parent.pm, obsolete
    Module::Install::Include and included Test::More.
* Mon Apr 13 2015 coolo@suse.com
- updated to 1.008
  see /usr/share/doc/packages/perl-PAR/Changes
* Thu Jan 10 2013 ro@suse.de
- update to 1.007
  - Hopefully fix "pp -C ..."
  - update to Module::Install 1.06
- update to 1.006
  - Fix RT #78633: PAR::import ignores url => $repo_client_object
  - Fix RT #73491: cache directory naming problem
- update to 1.005
  - bump Perl version requirement to 5.8.1
  - run all tests using a nonce PAR_TMPDIR
- update to 1.004
  - back out r1241
  - change "unsafe directory" error message
  - remove "debian" sub directory
  - remove some cruft from MANIFEST.SKIP
- update to 1.003
  - RT #69560/CVE-2011-4114
  - Fix a problem packing XML::LibXSLT on Windows
  - Die (with a hopefully useful message) if any error is encountered
    during an Archive::Zip extract operation
* Fri May 25 2012 werner@suse.de
- Adopt to spdx, then readme says "You can redistribute and/or modify
  this bundle under the same terms as Perl itself."
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Tue Nov 23 2010 pth@novell.com
- initial package 1.002
  * created by cpanspec 1.78
